Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/compositor/operations/COM_PixelateOperation.h')
-rw-r--r--source/blender/compositor/operations/COM_PixelateOperation.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/source/blender/compositor/operations/COM_PixelateOperation.h b/source/blender/compositor/operations/COM_PixelateOperation.h
index f8155e54f75..51a480b98e9 100644
--- a/source/blender/compositor/operations/COM_PixelateOperation.h
+++ b/source/blender/compositor/operations/COM_PixelateOperation.h
@@ -34,33 +34,33 @@ class PixelateOperation : public NodeOperation {
/**
* \brief cached reference to the input operation
*/
- SocketReader *inputOperation_;
+ SocketReader *input_operation_;
public:
/**
* \brief PixelateOperation
* \param dataType: the datatype to create this operator for (saves datatype conversions)
*/
- PixelateOperation(DataType dataType);
+ PixelateOperation(DataType data_type);
/**
* \brief initialization of the execution
*/
- void initExecution() override;
+ void init_execution() override;
/**
* \brief de-initialization of the execution
*/
- void deinitExecution() override;
+ void deinit_execution() override;
/**
- * \brief executePixel
+ * \brief execute_pixel
* \param output: result
* \param x: x-coordinate
* \param y: y-coordinate
* \param sampler: sampler
*/
- void executePixelSampled(float output[4], float x, float y, PixelSampler sampler) override;
+ void execute_pixel_sampled(float output[4], float x, float y, PixelSampler sampler) override;
};
} // namespace blender::compositor
@@ -34,33 +34,33 @@ class PixelateOperation : public NodeOperation {
/**
* \brief PixelateOperation
- * \param dataType: the datatype to create this operator for (saves datatype conversions)
+ * \param data_type: the datatype to create this operator for (saves datatype conversions)
*/